All of lore.kernel.org
 help / color / mirror / Atom feed
* Patch "nfc: st-nci: Fix typo when changing from st21nfcb to st-nci" has been added to the 4.2-stable tree
@ 2015-09-23  4:14 gregkh
  0 siblings, 0 replies; only message in thread
From: gregkh @ 2015-09-23  4:14 UTC (permalink / raw)
  To: christophe.ricard, christophe-h.ricard, gregkh, sameo
  Cc: stable, stable-commits


This is a note to let you know that I've just added the patch titled

    nfc: st-nci: Fix typo when changing from st21nfcb to st-nci

to the 4.2-stable tree which can be found at:
    http://www.kernel.org/git/?p=linux/kernel/git/stable/stable-queue.git;a=summary

The filename of the patch is:
     nfc-st-nci-fix-typo-when-changing-from-st21nfcb-to-st-nci.patch
and it can be found in the queue-4.2 subdirectory.

If you, or anyone else, feels it should not be added to the stable tree,
please let <stable@vger.kernel.org> know about it.


>From 30458aac63c89771d19f023083d64d018562812e Mon Sep 17 00:00:00 2001
From: Christophe Ricard <christophe.ricard@gmail.com>
Date: Fri, 14 Aug 2015 22:33:31 +0200
Subject: nfc: st-nci: Fix typo when changing from st21nfcb to st-nci

From: Christophe Ricard <christophe.ricard@gmail.com>

commit 30458aac63c89771d19f023083d64d018562812e upstream.

Replace ST21NFCB with ST_NCI or st21nfcb with st_nci as it
was forgotten in commit "nfc: st-nci: Rename st21nfcb to st-nci"
ed06aeefdac348cfb91a3db5fe1067e3202afd70

Signed-off-by: Christophe Ricard <christophe-h.ricard@st.com>
Signed-off-by: Samuel Ortiz <sameo@linux.intel.com>
Signed-off-by: Greg Kroah-Hartman <gregkh@linuxfoundation.org>

---
 drivers/nfc/st-nci/i2c.c |   18 +++++++++---------
 1 file changed, 9 insertions(+), 9 deletions(-)

--- a/drivers/nfc/st-nci/i2c.c
+++ b/drivers/nfc/st-nci/i2c.c
@@ -29,11 +29,11 @@
 
 #include "ndlc.h"
 
-#define DRIVER_DESC "NCI NFC driver for ST21NFCB"
+#define DRIVER_DESC "NCI NFC driver for ST_NCI"
 
 /* ndlc header */
-#define ST21NFCB_FRAME_HEADROOM	1
-#define ST21NFCB_FRAME_TAILROOM 0
+#define ST_NCI_FRAME_HEADROOM	1
+#define ST_NCI_FRAME_TAILROOM 0
 
 #define ST_NCI_I2C_MIN_SIZE 4   /* PCB(1) + NCI Packet header(3) */
 #define ST_NCI_I2C_MAX_SIZE 250 /* req 4.2.1 */
@@ -118,14 +118,14 @@ static int st_nci_i2c_write(void *phy_id
 /*
  * Reads an ndlc frame and returns it in a newly allocated sk_buff.
  * returns:
  * frame size : if received frame is complete (find ST21NFCB_SOF_EOF at
  * end of read)
  * -EAGAIN : if received frame is incomplete (not find ST21NFCB_SOF_EOF
  * at end of read)
  * -EREMOTEIO : i2c read error (fatal)
  * -EBADMSG : frame was incorrect and discarded
  * (value returned from st_nci_i2c_repack)
  * -EIO : if no ST21NFCB_SOF_EOF is found after reaching
  * the read length end sequence
  */
 static int st_nci_i2c_read(struct st_nci_i2c_phy *phy,
@@ -179,7 +179,7 @@ static int st_nci_i2c_read(struct st_nci
 /*
  * Reads an ndlc frame from the chip.
  *
  * On ST21NFCB, IRQ goes in idle state when read starts.
  */
 static irqreturn_t st_nci_irq_thread_fn(int irq, void *phy_id)
 {
@@ -325,12 +325,12 @@ static int st_nci_i2c_probe(struct i2c_c
 		}
 	} else {
 		nfc_err(&client->dev,
-			"st21nfcb platform resources not available\n");
+			"st_nci platform resources not available\n");
 		return -ENODEV;
 	}
 
 	r = ndlc_probe(phy, &i2c_phy_ops, &client->dev,
-			ST21NFCB_FRAME_HEADROOM, ST21NFCB_FRAME_TAILROOM,
+			ST_NCI_FRAME_HEADROOM, ST_NCI_FRAME_TAILROOM,
 			&phy->ndlc);
 	if (r < 0) {
 		nfc_err(&client->dev, "Unable to register ndlc layer\n");


Patches currently in stable-queue which might be from christophe.ricard@gmail.com are

queue-4.2/nfc-st-nci-fix-typo-when-changing-from-st21nfcb-to-st-nci.patch
queue-4.2/nfc-st-nci-remove-duplicate-file-platform_data-st_nci.h.patch
queue-4.2/nfc-st-nci-fix-non-accurate-comment-for-st_nci_i2c_read.patch
queue-4.2/nfc-st-nci-free-data-with-irrelevant-ndlc-pcb_sync-value.patch
queue-4.2/nfc-st-nci-fix-use-of-uninitialized-variables-in-error-path.patch
queue-4.2/nfc-netlink-warning-fix.patch
queue-4.2/nfc-st-nci-remove-data-from-ack_pending_q-when-receiving-a-sync_ack.patch
queue-4.2/nfc-netlink-add-check-on-nfc_attr_vendor_data.patch
queue-4.2/nfc-nci-hci-add-check-on-skb-nci_hci_send_cmd-parameter.patch
queue-4.2/nfc-st21nfca-fix-use-of-uninitialized-variables-in-error-path.patch

^ permalink raw reply	[flat|nested] only message in thread

only message in thread, other threads:[~2015-09-23  4:15 UTC | newest]

Thread overview: (only message) (download: mbox.gz follow: Atom feed
-- links below jump to the message on this page --
@@ -118,14 +118,14 @@ static int st_nci_i2c_write(void *phy_id
  * Reads an ndlc frame and returns it in a newly allocated sk_buff.
  * returns:
- * frame size : if received frame is complete (find ST21NFCB_SOF_EOF at
+ * frame size : if received frame is complete (find ST_NCI_SOF_EOF at
  * end of read)
@@ -118,14 +118,14 @@ static int st_nci_i2c_write(void *phy_id
  * end of read)
- * -EAGAIN : if received frame is incomplete (not find ST21NFCB_SOF_EOF
+ * -EAGAIN : if received frame is incomplete (not find ST_NCI_SOF_EOF
  * at end of read)
  * -EREMOTEIO : i2c read error (fatal)
@@ -118,14 +118,14 @@ static int st_nci_i2c_write(void *phy_id
  * -EBADMSG : frame was incorrect and discarded
  * (value returned from st_nci_i2c_repack)
- * -EIO : if no ST21NFCB_SOF_EOF is found after reaching
+ * -EIO : if no ST_NCI_SOF_EOF is found after reaching
  * the read length end sequence
  */
@@ -179,7 +179,7 @@ static int st_nci_i2c_read(struct st_nci
  * Reads an ndlc frame from the chip.
  *
- * On ST21NFCB, IRQ goes in idle state when read starts.
+ * On ST_NCI, IRQ goes in idle state when read starts.
  */
 static irqreturn_t st_nci_irq_thread_fn(int irq, void *phy_id)
2015-09-23  4:14 Patch "nfc: st-nci: Fix typo when changing from st21nfcb to st-nci" has been added to the 4.2-stable tree gregkh

This is an external index of several public inboxes,
see mirroring instructions on how to clone and mirror
all data and code used by this external index.